pub struct MappedMutexGuard<'a, T>where
T: ?Sized,{ /* private fields */ }Expand description
A handle to a held Mutex that has had a function applied to it via MutexGuard::map.
This can be used to hold a subfield of the protected data.
Implementations
Sourceimpl<'a, T> MappedMutexGuard<'a, T>where
T: ?Sized,
impl<'a, T> MappedMutexGuard<'a, T>where
T: ?Sized,
Sourcepub fn map<U, F>(this: MappedMutexGuard<'a, T>, f: F) -> MappedMutexGuard<'a, U>
pub fn map<U, F>(this: MappedMutexGuard<'a, T>, f: F) -> MappedMutexGuard<'a, U>
Makes a new MappedMutexGuard for a component of the locked data.
This operation cannot fail as the MappedMutexGuard passed in already locked the mutex.
This is an associated function that needs to be used as MappedMutexGuard::map(...). A
method would interfere with methods of the same name on the contents of the locked data.
Sourcepub fn try_map<U, F>(
this: MappedMutexGuard<'a, T>,
f: F,
) -> Result<MappedMutexGuard<'a, U>, MappedMutexGuard<'a, T>>
pub fn try_map<U, F>( this: MappedMutexGuard<'a, T>, f: F, ) -> Result<MappedMutexGuard<'a, U>, MappedMutexGuard<'a, T>>
Attempts to make a new MappedMutexGuard for a component of the locked data. The
original guard is returned if the closure returns None.
This operation cannot fail as the MappedMutexGuard passed in already locked the mutex.
This is an associated function that needs to be used as MappedMutexGuard::try_map(...). A
method would interfere with methods of the same name on the contents of the locked data.