OwnedMutexGuard

Struct OwnedMutexGuard 

pub struct OwnedMutexGuard<T>
where T: ?Sized,
{ /* private fields */ }
An owned handle to a held Mutex.

This guard is only available from a Mutex that is wrapped in an Arc. It is identical to MutexGuard, except that rather than borrowing the Mutex, it clones the Arc, incrementing the reference count. This means that unlike MutexGuard, it will have the 'static lifetime.

As long as you have this guard, you have exclusive access to the underlying T. The guard internally keeps a reference-counted pointer to the original Mutex, so even if the lock goes away, the guard remains valid.

The lock is automatically released whenever the guard is dropped, at which point lock will succeed yet again.

Implementations

Source

impl<T> OwnedMutexGuard<T>
where T: ?Sized,

pub fn map<U, F>(this: OwnedMutexGuard<T>, f: F) -> OwnedMappedMutexGuard<T, U>
where F: FnOnce(&mut T) -> &mut U, U: ?Sized,

Makes a new OwnedMappedMutexGuard for a component of the locked data.

This operation cannot fail as the OwnedMutexGuard passed in already locked the mutex.

This is an associated function that needs to be used as OwnedMutexGuard::map(...). A method would interfere with methods of the same name on the contents of the locked data.

Examples
use tokio::sync::{Mutex, OwnedMutexGuard};
use std::sync::Arc;

#[derive(Debug, Clone, Copy, PartialEq, Eq)]
struct Foo(u32);

let foo = Arc::new(Mutex::new(Foo(1)));

{
    let mut mapped = OwnedMutexGuard::map(foo.clone().lock_owned().await, |f| &mut f.0);
    *mapped = 2;
}

assert_eq!(Foo(2), *foo.lock().await);
pub fn try_map<U, F>( this: OwnedMutexGuard<T>, f: F, ) -> Result<OwnedMappedMutexGuard<T, U>, OwnedMutexGuard<T>>
where F: FnOnce(&mut T) -> Option<&mut U>, U: ?Sized,

Attempts to make a new OwnedMappedMutexGuard for a component of the locked data. The original guard is returned if the closure returns None.

This operation cannot fail as the OwnedMutexGuard passed in already locked the mutex.

This is an associated function that needs to be used as OwnedMutexGuard::try_map(...). A method would interfere with methods of the same name on the contents of the locked data.

Examples
use tokio::sync::{Mutex, OwnedMutexGuard};
use std::sync::Arc;

#[derive(Debug, Clone, Copy, PartialEq, Eq)]
struct Foo(u32);

let foo = Arc::new(Mutex::new(Foo(1)));

{
    let mut mapped = OwnedMutexGuard::try_map(foo.clone().lock_owned().await, |f| Some(&mut f.0))
        .expect("should not fail");
    *mapped = 2;
}

assert_eq!(Foo(2), *foo.lock().await);
pub fn mutex(this: &OwnedMutexGuard<T>) -> &Arc<Mutex<T>> ⓘ

Returns a reference to the original Arc<Mutex>.

use std::sync::Arc;
use tokio::sync::{Mutex, OwnedMutexGuard};

async fn unlock_and_relock(guard: OwnedMutexGuard<u32>) -> OwnedMutexGuard<u32> {
    println!("1. contains: {:?}", *guard);
    let mutex: Arc<Mutex<u32>> = OwnedMutexGuard::mutex(&guard).clone();
    drop(guard);
    let guard = mutex.lock_owned().await;
    println!("2. contains: {:?}", *guard);
    guard
}