pub trait FutureSendStatic<T>:
Future<Output = T>
+ Send
+ 'static { }Expand description
A trait for futures that are sendable and have a static lifetime.
This marker trait simplifies generic bounds for asynchronous operations, ensuring that futures can be safely managed by the async runtime without lifetime issues.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementors
impl<T, R> FutureSendStatic<R> for T
A blanket implementation for any future that is sendable and has a static lifetime.
This is a convenient trait for working with futures in an asynchronous context, ensuring that they can be safely managed by the async runtime across different threads.